package com.example.sensor;

import java.io.IOException;
import java.io.PrintWriter;
import java.net.ServerSocket;
import java.net.Socket;
import java.net.SocketTimeoutException;
import java.util.Scanner;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;
import android.os.Bundle;
import android.os.Handler;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.TextView;
import android.widget.Toast;


public class ProximityFlow extends Activity implements SensorEventListener, OnClickListener {
	  private SensorManager mSensorManager;
	  private Sensor mProximity;

	  // For LOG, which is writing output data to LogCat
	  // filter can be set for listening this word
	  public static final String TAG = "Connection";
	  public static final int TIMEOUT = 10;
	  Intent i = null;
	  private String connectionStatus = null;
	  private String socketData = null;
	  private Handler mHandler = null;
	  ServerSocket server = null;
	  
	  private TextView tv, tv1, tv2;

	  @Override
	  public final void onCreate(Bundle savedInstanceState) {
	    super.onCreate(savedInstanceState);
	    setContentView(R.layout.activity_sensor);

	    // Get an instance of the sensor service, and use that to get an instance of
	    // a particular sensor.
	    mSensorManager = (SensorManager) getSystemService(Context.SENSOR_SERVICE);
	    mProximity = mSensorManager.getDefaultSensor(Sensor.TYPE_PROXIMITY);

		tv = (TextView) findViewById(R.id.connection_text);
	    tv1 = (TextView) findViewById(R.id.textView3);
	    tv2 = (TextView) findViewById(R.id.textView4);

	    tv.setText("Nepřipojeno");
    	tv1.setText("NON ACTIVE!");

		View connectButton = findViewById(R.id.button1);
		connectButton.setOnClickListener(this);

		mHandler = new Handler();
	  }

	  @Override
	  public final void onAccuracyChanged(Sensor sensor, int accuracy) {
		  tv2.setText(""+accuracy);
	  }

	  @Override
	  public final void onSensorChanged(SensorEvent event) {
	    if(event.values[0]==0)
	    	tv1.setText("ACTIVE!");
	    else
	    	tv1.setText("NON ACTIVE!");
	    
	    sendText((event.values[0]==0 ? "0" : "1"));
	  }

	  @Override
	  protected void onResume() {
	    // Register a listener for the sensor.
	    super.onResume();
	    mSensorManager.registerListener(this, mProximity, SensorManager.SENSOR_DELAY_NORMAL);
	  }

	  @Override
	  protected void onPause() {
	    // Be sure to unregister the sensor when the activity pauses.
	    super.onPause();
	    mSensorManager.unregisterListener(this);
	  }

	@Override
	public void onClick(View v) {
		switch (v.getId()) {
		case R.id.button1:
			// initialize server socket in a new separate thread
			String msg = "Pokus o připojení k NB...";
			setText(msg);
			new Thread(initializeConnection).start();
			Toast.makeText(this, msg, msg.length()).show();
			break;
		}
	}

	private Runnable initializeConnection = new Thread() {
		public void run() {
			Socket client = null;
			// initialize server socket
			try {
				server = new ServerSocket(38300);
				server.setSoTimeout(TIMEOUT * 1000);

				// attempt to accept a connection
				client = server.accept();
				Globals.socketIn = new Scanner(client.getInputStream());
				Globals.socketOut = new PrintWriter(client.getOutputStream(), true);

				// Globals.socketIn.
			} catch (SocketTimeoutException e) {
				// print out TIMEOUT
				setText("Čas vypršel, zkus se připojit znovu.");
				connectionStatus = "Čas vypršel, zkus se připojit znovu.";
				mHandler.post(showConnectionStatus);
			} catch (IOException e) {
				Log.e(TAG, "" + e);
			} finally {
				// close the server socket
				try {
					if (server != null)
						server.close();
				} catch (IOException ec) {
					setText("Nelze uzavřít socket serveru: " + ec);
					Log.e(TAG, "Nelze uzavřít socket serveru: " + ec);
				}
			}

			if (client != null) {
				Globals.connected = true;
				// print out success
				connectionStatus = "Spojení s NB navázáno!";
				setText("Spojení s NB navázáno!");
				Log.d(TAG, "navázáno!");
				mHandler.post(showConnectionStatus);
				while (Globals.socketIn.hasNext()) {
					socketData = Globals.socketIn.next();
					mHandler.post(socketStatus);

				}
			}
			else
				setText("Nepřipojeno!");
		}
	};
	
	private void setText(String text) {
		//tv.setText(text);
	}

	private void sendText(String text) {
		if (Globals.socketOut != null) {
			Globals.socketOut.println(text);
			Globals.socketOut.flush();
		}
	}

	/**
	 * Pops up a "toast"/bubble to indicate the connection status
	 */
	private Runnable showConnectionStatus = new Runnable() {
		public void run() {
			Toast.makeText(getBaseContext(), connectionStatus, Toast.LENGTH_SHORT).show();
		}
	};

	private Runnable socketStatus = new Runnable() {
		public void run() {
			TextView tv = (TextView) findViewById(R.id.connection_text);
			tv.setText(socketData);
		}
	};

	public static class Globals {
		public static boolean connected;
		public static Scanner socketIn;
		public static PrintWriter socketOut;
	}

}